/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizactivate.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizactivate.entity.BizActivate;
import vip.xiaonuo.biz.modular.bizactivate.param.BizActivateAddParam;
import vip.xiaonuo.biz.modular.bizactivate.param.BizActivateEditParam;
import vip.xiaonuo.biz.modular.bizactivate.param.BizActivateIdParam;
import vip.xiaonuo.biz.modular.bizactivate.param.BizActivatePageParam;
import vip.xiaonuo.biz.modular.bizactivate.service.BizActivateService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 用户充值待激活记录控制器
 *
 * @author fanzherong
 * @date  2025/02/27 16:36
 */
@Tag(name = "用户充值待激活记录控制器")
@RestController
@Validated
public class BizActivateController {

    @Resource
    private BizActivateService bizActivateService;

    /**
     * 获取用户充值待激活记录分页
     *
     * @author fanzherong
     * @date  2025/02/27 16:36
     */
    @Operation(summary = "获取用户充值待激活记录分页")
    @SaCheckPermission("/biz/bizactivate/page")
    @GetMapping("/biz/bizactivate/page")
    public CommonResult<Page<BizActivate>> page(BizActivatePageParam bizActivatePageParam) {
        return CommonResult.data(bizActivateService.page(bizActivatePageParam));
    }

    /**
     * 添加用户充值待激活记录
     *
     * @author fanzherong
     * @date  2025/02/27 16:36
     */
    @Operation(summary = "添加用户充值待激活记录")
    @CommonLog("添加用户充值待激活记录")
    @SaCheckPermission("/biz/bizactivate/add")
    @PostMapping("/biz/bizactivate/add")
    public CommonResult<String> add(@RequestBody @Valid BizActivateAddParam bizActivateAddParam) {
        bizActivateService.add(bizActivateAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑用户充值待激活记录
     *
     * @author fanzherong
     * @date  2025/02/27 16:36
     */
    @Operation(summary = "编辑用户充值待激活记录")
    @CommonLog("编辑用户充值待激活记录")
    @SaCheckPermission("/biz/bizactivate/edit")
    @PostMapping("/biz/bizactivate/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizActivateEditParam bizActivateEditParam) {
        bizActivateService.edit(bizActivateEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除用户充值待激活记录
     *
     * @author fanzherong
     * @date  2025/02/27 16:36
     */
    @Operation(summary = "删除用户充值待激活记录")
    @CommonLog("删除用户充值待激活记录")
    @SaCheckPermission("/biz/bizactivate/delete")
    @PostMapping("/biz/bizactivate/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizActivateIdParam> bizActivateIdParamList) {
        bizActivateService.delete(bizActivateIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取用户充值待激活记录详情
     *
     * @author fanzherong
     * @date  2025/02/27 16:36
     */
    @Operation(summary = "获取用户充值待激活记录详情")
    @SaCheckPermission("/biz/bizactivate/detail")
    @GetMapping("/biz/bizactivate/detail")
    public CommonResult<BizActivate> detail(@Valid BizActivateIdParam bizActivateIdParam) {
        return CommonResult.data(bizActivateService.detail(bizActivateIdParam));
    }
}
