/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizactivatedetail.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizactivatedetail.entity.BizActivateDetail;
import vip.xiaonuo.biz.modular.bizactivatedetail.mapper.BizActivateDetailMapper;
import vip.xiaonuo.biz.modular.bizactivatedetail.param.BizActivateDetailAddParam;
import vip.xiaonuo.biz.modular.bizactivatedetail.param.BizActivateDetailEditParam;
import vip.xiaonuo.biz.modular.bizactivatedetail.param.BizActivateDetailIdParam;
import vip.xiaonuo.biz.modular.bizactivatedetail.param.BizActivateDetailPageParam;
import vip.xiaonuo.biz.modular.bizactivatedetail.service.BizActivateDetailService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;

import java.util.List;

/**
 * 激活明细Service接口实现类
 *
 * @author fanzherong
 * @date  2025/03/05 14:33
 **/
@Service
public class BizActivateDetailServiceImpl extends ServiceImpl<BizActivateDetailMapper, BizActivateDetail> implements BizActivateDetailService {

    @Override
    public Page<BizActivateDetail> page(BizActivateDetailPageParam bizActivateDetailPageParam) {
        QueryWrapper<BizActivateDetail> queryWrapper = new QueryWrapper<BizActivateDetail>().checkSqlInjection();
        if(ObjectUtil.isNotEmpty(bizActivateDetailPageParam.getActivateId())){
            queryWrapper.eq("bad.activate_id",bizActivateDetailPageParam.getActivateId());
        }
        Page<BizActivateDetail> pageList = this.getBaseMapper().getPageList(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizActivateDetail bizActivateDetail: pageList.getRecords()){
            bizActivateDetail.setPhone(CommonCryptogramUtil.doSm4CbcDecrypt(bizActivateDetail.getPhone()));
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizActivateDetailAddParam bizActivateDetailAddParam) {
        BizActivateDetail bizActivateDetail = BeanUtil.toBean(bizActivateDetailAddParam, BizActivateDetail.class);
        this.save(bizActivateDetail);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizActivateDetailEditParam bizActivateDetailEditParam) {
        BizActivateDetail bizActivateDetail = this.queryEntity(bizActivateDetailEditParam.getId());
        BeanUtil.copyProperties(bizActivateDetailEditParam, bizActivateDetail);
        this.updateById(bizActivateDetail);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizActivateDetailIdParam> bizActivateDetailIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizActivateDetailIdParamList, BizActivateDetailIdParam::getId));
    }

    @Override
    public BizActivateDetail detail(BizActivateDetailIdParam bizActivateDetailIdParam) {
        return this.queryEntity(bizActivateDetailIdParam.getId());
    }

    @Override
    public BizActivateDetail queryEntity(String id) {
        BizActivateDetail bizActivateDetail = this.getById(id);
        if(ObjectUtil.isEmpty(bizActivateDetail)) {
            throw new CommonException("激活明细不存在，id值为：{}", id);
        }
        return bizActivateDetail;
    }
}
