/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.recommendrecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.auth.core.util.StpLoginUserUtil;
import vip.xiaonuo.common.enums.CommonDeleteFlagEnum;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.recommendrecord.entity.BizRecommendRecord;
import vip.xiaonuo.biz.modular.recommendrecord.mapper.BizRecommendRecordMapper;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordAddParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordEditParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordIdParam;
import vip.xiaonuo.biz.modular.recommendrecord.param.BizRecommendRecordPageParam;
import vip.xiaonuo.biz.modular.recommendrecord.service.BizRecommendRecordService;
import vip.xiaonuo.common.util.CommonCryptogramUtil;

import java.util.List;

/**
 * 推荐记录表Service接口实现类
 *
 * @author wulei
 * @date 2025/02/06 17:42
 **/
@Service
public class BizRecommendRecordServiceImpl extends ServiceImpl<BizRecommendRecordMapper, BizRecommendRecord> implements BizRecommendRecordService {

    @Override
    public Page<BizRecommendRecord> page(BizRecommendRecordPageParam bizRecommendRecordPageParam) {
        QueryWrapper<BizRecommendRecord> queryWrapper = new QueryWrapper<BizRecommendRecord>().checkSqlInjection();
        if (ObjectUtil.isNotEmpty(bizRecommendRecordPageParam.getSearchKey())) {
            queryWrapper.and(s -> s.like("u2.NAME", bizRecommendRecordPageParam.getSearchKey())
                    .or().like("u2.ACCOUNT", bizRecommendRecordPageParam.getSearchKey()));
        }
        queryWrapper.eq("t.delete_flag", CommonDeleteFlagEnum.NOT_DELETE);
        queryWrapper.orderByAsc("t.create_time");
        Page<BizRecommendRecord> page = baseMapper.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizRecommendRecord bizRecommendRecord : page.getRecords()){
            if(ObjectUtil.isNotEmpty(bizRecommendRecord.getRecommendUserPhone())){
                bizRecommendRecord.setRecommendUserPhone(CommonCryptogramUtil.doSm4CbcDecrypt(bizRecommendRecord.getRecommendUserPhone()));
            }
            if(ObjectUtil.isNotEmpty(bizRecommendRecord.getAcceptUserPhone())){
                bizRecommendRecord.setAcceptUserPhone(CommonCryptogramUtil.doSm4CbcDecrypt(bizRecommendRecord.getAcceptUserPhone()));
            }
        }
        return page;
    }

    @Override
    public Page<BizRecommendRecord> userPage(BizRecommendRecordPageParam bizRecommendRecordPageParam) {
        QueryWrapper<BizRecommendRecord> queryWrapper = new QueryWrapper<BizRecommendRecord>().checkSqlInjection();
        if (ObjectUtil.isNotEmpty(bizRecommendRecordPageParam.getSearchKey())) {
            queryWrapper.and(s -> s.like("u1.NAME", bizRecommendRecordPageParam.getSearchKey())
                    .or().like("u1.ACCOUNT", bizRecommendRecordPageParam.getSearchKey()));
        }
        queryWrapper.eq("t.recommend_user_id", StpLoginUserUtil.getLoginUser().getId());
        queryWrapper.eq("t.delete_flag", CommonDeleteFlagEnum.NOT_DELETE);
        queryWrapper.orderByAsc("t.create_time");
        return baseMapper.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Override
    public BizRecommendRecord detail(BizRecommendRecordIdParam bizRecommendRecordIdParam) {
        return this.queryEntity(bizRecommendRecordIdParam.getId());
    }

    @Override
    public BizRecommendRecord queryEntity(String id) {
        BizRecommendRecord bizRecommendRecord = this.getById(id);
        if (ObjectUtil.isEmpty(bizRecommendRecord)) {
            throw new CommonException("推荐记录表不存在，id值为：{}", id);
        }
        return bizRecommendRecord;
    }
}
